@@ -27,7 +27,7 @@ from .literals import (
     ValidatorTypeType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -160,7 +160,7 @@ ConfigurationProfilesTypeDef = TypedDict(
 ConfigurationTypeDef = TypedDict(
     "ConfigurationTypeDef",
     {
-        "Content": bytes,
+        "Content": StreamingBody,
         "ConfigurationVersion": str,
         "ContentType": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -561,7 +561,7 @@ HostedConfigurationVersionTypeDef = TypedDict(
         "ConfigurationProfileId": str,
         "VersionNumber": int,
         "Description": str,
-        "Content": bytes,
+        "Content": StreamingBody,
         "ContentType": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
